@@ -44,7 +44,6 @@ class Whups_Api extends Horde_Registry_Api
                                                  'queue', Horde_Perms::READ))));
         } else {
             $path = explode('/', $path);
-            Horde::log(var_export($path, true), 'INFO');
             $results = array();
 
             switch ($path[0]) {
@@ -394,10 +393,8 @@ class Whups_Api extends Horde_Registry_Api
 
                 $result['whups/' . $ticket['id']] = array(
                     'task_id'           => $ticket['id'],
-                    'priority'          => $ticket['priority_name'],
-                    'tasklist_id'       => '**EXTERNAL**',
                     'completed'         => ($ticket['state_category'] == 'resolved'),
-                    'name'              => '[#' . $ticket['id'] . '] ' . $ticket['summary'],
+                    'name'              => '[' . _("Ticket") . ' #' . $ticket['id'] . '] ' . $ticket['summary'],
                     'desc'              => null,
                     'due'               => null,
                     'category'          => null,
@@ -611,7 +608,8 @@ class Whups_Api extends Horde_Registry_Api
              * hour estimates. */
             $attributes = $whups_driver->getTicketAttributesWithNames($ticket['id']);
             foreach ($attributes as $k => $v) {
-                if (strtolower($k) == _("estimated time")) {
+                if (Horde_String::lower($k) == _("estimated time") ||
+                    Horde_String::lower($k) == 'estimated time') {
                     if (!empty($v)) {
                         $result[$ticket['id']]['estimate'] = (double) $v;
                     }
