@@ -3,7 +3,7 @@
  * Base class for Whups' storage backend.
  *
  * Copyright 2001-2002 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2001-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -510,11 +510,14 @@ abstract class Whups_Driver
                 continue;
             }
 
-            if ($details && $details['type'] == 'user') {
+            if ($details &&
+                $details['type'] == 'user') {
                 $user_prefs = $GLOBALS['injector']
                     ->getInstance('Horde_Core_Factory_Prefs')
                     ->create('whups', array('user' => $details['user']));
-                if ($from['type'] == 'user' &&
+                if (($details['user'] == $registry->getAuth() ||
+                     (!$registry->getAuth())) &&
+                    $from['type'] == 'user' &&
                     $details['user'] == $from['user'] &&
                     $user_prefs->getValue('email_others_only')) {
                     continue;
