@@ -2,7 +2,7 @@
 /**
  * This file contains all Horde_Form classes for ticket type administration.
  *
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -25,11 +25,11 @@ class Whups_Form_Admin_CloneType extends Horde_Form
         $this->setButtons(_("Clone"));
         $this->addHidden('', 'type', 'int', true, true);
 
-        $tname = &$this->addVariable(
+        $tname = $this->addVariable(
             _("Name of the cloned copy"), 'name', 'text', true);
         $tname->setDefault(sprintf(_("Copy of %s"), $info['name']));
 
-        $tdesc = &$this->addVariable(
+        $tdesc = $this->addVariable(
             _("Clone Description"), 'description', 'text', true);
         $tdesc->setDefault($info['description']);
     }
