@@ -2,7 +2,7 @@
 /**
  * This file contains all Horde_Form classes for ticket state administration.
  *
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -31,7 +31,7 @@ class Whups_Form_Admin_DefaultState extends Horde_Form
         }
 
         $this->addHidden('', 'type', 'int', true, true);
-        $var = &$this->addVariable(
+        $var = $this->addVariable(
             _("State Name"), 'state', $stype, false, false, null, $type_params);
         $var->setDefault($GLOBALS['whups_driver']->getDefaultState($vars->get('type')));
     }
