@@ -2,7 +2,7 @@
 /**
  * This file contains all Horde_Form classes for priority administration.
  *
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -25,10 +25,10 @@ class Whups_Form_Admin_EditPriorityStepTwo extends Horde_Form
         $this->addHidden('', 'type', 'int', true, true);
         $this->addHidden('', 'priority', 'int', true, true);
 
-        $pname = &$this->addVariable(_("Priority Name"), 'name', 'text', true);
+        $pname = $this->addVariable(_("Priority Name"), 'name', 'text', true);
         $pname->setDefault($info['name']);
 
-        $pdesc = &$this->addVariable(_("Priority Description"), 'description', 'text', true);
+        $pdesc = $this->addVariable(_("Priority Description"), 'description', 'text', true);
         $pdesc->setDefault($info['description']);
     }
 
