@@ -1,7 +1,7 @@
 <?php
 /**
  * Copyright 2001-2002 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2001-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -17,7 +17,7 @@ class Whups_Form_Ticket_Delete extends Horde_Form
         $info = $GLOBALS['whups_driver']->getTicketDetails($vars->get('id'));
         $this->_queue = $info['queue'];
         $this->addHidden('', 'id', 'int', true, true);
-        $summary = &$this->addVariable(_("Summary"), 'summary', 'text', false,
+        $summary = $this->addVariable(_("Summary"), 'summary', 'text', false,
                                        true);
         $summary->setDefault($info['summary']);
         $yesno = array(0 => _("No"), 1 => _("Yes"));
