@@ -3,7 +3,7 @@
  * The Whups_Ticket class encapsulates some logic relating to tickets, sending
  * updates, etc.
  *
- * Copyright 2004-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2004-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -110,6 +110,7 @@ class Whups_Ticket
         }
 
         // Check for a deferred attachment upload.
+        $a_name = null;
         if (!empty($info['deferred_attachment']) &&
             ($a_name = $GLOBALS['session']->get('whups', 'deferred_attachment/' . $info['deferred_attachment']))) {
             $ticket->change(
@@ -117,7 +118,6 @@ class Whups_Ticket
                 array(
                     'name' => $info['deferred_attachment'],
                     'tmp_name' => $a_name));
-            unlink($a_name);
         }
 
         // Check for manually added attachments.
@@ -131,6 +131,12 @@ class Whups_Ticket
             $info['last-transaction'],
             false);
 
+        // Delete deferred attachment now, because it will be attached in the
+        // commit() call above.
+        if ($a_name) {
+            unlink($a_name);
+        }
+
         // Send email notifications.
         $ticket->notify($ticket->get('user_id_requester'), true);
 
